==> realestate-supervise-common-1.0.0-20190527.033121-2-sources.jar: cn/gtmap/realestate/supervise/entity/BaFdcq2.java <==
package cn.gtmap.realestate.supervise.entity;


import cn.gtmap.realestate.supervise.core.reflect.*;
import com.sun.istack.internal.Nullable;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.*;
import java.io.Serializable;
import java.util.Date;
/**
 * @author <a href="mailto:gaofeng@gtmap.cn">gaofeng</a>
 * @version 1.0，2017/6/15
 * @description QLT_FW_FDCQ_YZ  房地产权（独幢、层、套、间房屋）属性结构
 */

@XmlAccessorType(XmlAccessType.FIELD)
@XmlRootElement
@XmlType
@Entity
@Table(
        name = "ba_fdcq2"
)
public class BaFdcq2 implements Serializable {


    @XmlAttribute
    @Id
    @id
    private String id;


    @XmlAttribute
	private String ysdm;

    @XmlAttribute
	private String bdcdyh;

    @XmlAttribute
    @Nullable
    @ywh
	private String ywh;

    @XmlAttribute
	private String qllx;

    @XmlAttribute
	private String djlx;

    @XmlAttribute
	private String djyy;

    @XmlAttribute
	private String fdzl;

    @XmlAttribute
    @encrypt
	private String tdsyqr;

    @XmlAttribute
    @Nullable
	private String dytdmj;

    @XmlAttribute
    @Nullable
	private String fttdmj;

    @XmlAttribute
	private Date tdsyqssj;

    @XmlAttribute
	private Date tdsyjssj;

    @XmlAttribute
    @Nullable
	private String fdcjyjg;

    @XmlAttribute
	private String ghyt;

    @XmlAttribute
    @Nullable
	private String fwxz;

    @XmlAttribute
    @Nullable
	private String fwjg;

    @XmlAttribute
	private String szc;

    @XmlAttribute
	private int zcs;

    @XmlAttribute
	private float jzmj;

    @XmlAttribute
	private float zyjzmj;

    @XmlAttribute
	private float ftjzmj;

    @XmlAttribute
    @Nullable
	private String jgsj;

    @XmlAttribute
    @Nullable
	private String bdcqzh;

    @XmlAttribute
    @qxdm
	private String qxdm;

    @XmlAttribute
	private String djjg;

    @XmlAttribute
	private String dbr;

    @XmlAttribute
	private Date djsj;

    @XmlAttribute
    @Nullable
	private String fj;

    @XmlAttribute
	private String qszt;

    @Nullable
    private Date sjgxsj;

    @bwmc
    private String bwmc;

    public String getBwmc() {
        return bwmc;
    }

    public void setBwmc(String bwmc) {
        this.bwmc = bwmc;
    }

    public Date getSjgxsj() {
        return sjgxsj;
    }

    public void setSjgxsj(Date sjgxsj) {
        this.sjgxsj = sjgxsj;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getYsdm() {
        return ysdm;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public String getYwh() {
        return ywh;
    }

    public String getQllx() {
        return qllx;
    }

    public String getDjlx() {
        return djlx;
    }

    public String getDjyy() {
        return djyy;
    }

    public String getFdzl() {
        return fdzl;
    }

    public String getTdsyqr() {
        return tdsyqr;
    }

    public String getDytdmj() {
        return dytdmj;
    }

    public String getFttdmj() {
        return fttdmj;
    }

    public Date getTdsyqssj() {
        return tdsyqssj;
    }

    public Date getTdsyjssj() {
        return tdsyjssj;
    }

    public String getFdcjyjg() {
        return fdcjyjg;
    }

    public String getGhyt() {
        return ghyt;
    }

    public String getFwxz() {
        return fwxz;
    }

    public String getFwjg() {
        return fwjg;
    }

    public String getSzc() {
        return szc;
    }

    public int getZcs() {
        return zcs;
    }

    public float getJzmj() {
        return jzmj;
    }

    public float getZyjzmj() {
        return zyjzmj;
    }

    public float getFtjzmj() {
        return ftjzmj;
    }

    public String getJgsj() {
        return jgsj;
    }

    public String getBdcqzh() {
        return bdcqzh;
    }

    public String getQxdm() {
        return qxdm;
    }

    public String getDjjg() {
        return djjg;
    }

    public String getDbr() {
        return dbr;
    }

    public Date getDjsj() {
        return djsj;
    }

    public String getFj() {
        return fj;
    }

    public String getQszt() {
        return qszt;
    }


    public void setYsdm(String ysdm) {
        this.ysdm = ysdm;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public void setDjlx(String djlx) {
        this.djlx = djlx;
    }

    public void setDjyy(String djyy) {
        this.djyy = djyy;
    }

    public void setFdzl(String fdzl) {
        this.fdzl = fdzl;
    }

    public void setTdsyqr(String tdsyqr) {
        this.tdsyqr = tdsyqr;
    }

    public void setDytdmj(String dytdmj) {
        this.dytdmj = dytdmj;
    }

    public void setFttdmj(String fttdmj) {
        this.fttdmj = fttdmj;
    }

    public void setTdsyqssj(Date tdsyqssj) {
        this.tdsyqssj = tdsyqssj;
    }

    public void setTdsyjssj(Date tdsyjssj) {
        this.tdsyjssj = tdsyjssj;
    }

    public void setFdcjyjg(String fdcjyjg) {
        this.fdcjyjg = fdcjyjg;
    }

    public void setGhyt(String ghyt) {
        this.ghyt = ghyt;
    }

    public void setFwxz(String fwxz) {
        this.fwxz = fwxz;
    }

    public void setFwjg(String fwjg) {
        this.fwjg = fwjg;
    }

    public void setSzc(String szc) {
        this.szc = szc;
    }

    public void setZcs(int zcs) {
        this.zcs = zcs;
    }

    public void setJzmj(float jzmj) {
        this.jzmj = jzmj;
    }

    public void setZyjzmj(float zyjzmj) {
        this.zyjzmj = zyjzmj;
    }

    public void setFtjzmj(float ftjzmj) {
        this.ftjzmj = ftjzmj;
    }

    public void setJgsj(String jgsj) {
        this.jgsj = jgsj;
    }

    public void setBdcqzh(String bdcqzh) {
        this.bdcqzh = bdcqzh;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }

    public void setDjjg(String djjg) {
        this.djjg = djjg;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public void setQszt(String qszt) {
        this.qszt = qszt;
    }

}

==> realestate-supervise-common-1.0.0-20210224.062454-42-sources.jar: cn/gtmap/realestate/supervise/entity/BaFdcq2.java <==
package cn.gtmap.realestate.supervise.entity;


import cn.gtmap.realestate.supervise.core.reflect.*;
import com.sun.istack.internal.Nullable;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.*;
import java.io.Serializable;
import java.util.Date;
/**
 * @author <a href="mailto:gaofeng@gtmap.cn">gaofeng</a>
 * @version 1.0，2017/6/15
 * @description QLT_FW_FDCQ_YZ  房地产权（独幢、层、套、间房屋）属性结构
 */

@XmlAccessorType(XmlAccessType.FIELD)
@XmlRootElement
@XmlType
@Entity
@Table(
        name = "ba_fdcq2"
)
public class BaFdcq2 implements Serializable {


    @XmlAttribute
    @Id
    @id
    private String id;


    @XmlAttribute
	private String ysdm;

    @XmlAttribute
	private String bdcdyh;

    @XmlAttribute
    @Nullable
    @ywh
	private String ywh;

    @XmlAttribute
	private String qllx;

    @XmlAttribute
	private String djlx;

    @XmlAttribute
	private String djyy;

    @XmlAttribute
	private String fdzl;

    @XmlAttribute
    @encrypt
	private String tdsyqr;

    @XmlAttribute
    @Nullable
	private String dytdmj;

    @XmlAttribute
    @Nullable
	private String fttdmj;

    @XmlAttribute
	private Date tdsyqssj;

    @XmlAttribute
	private Date tdsyjssj;

    @XmlAttribute
    @Nullable
	private String fdcjyjg;

    @XmlAttribute
	private String ghyt;

    @XmlAttribute
    @Nullable
	private String fwxz;

    @XmlAttribute
    @Nullable
	private String fwjg;

    @XmlAttribute
	private String szc;

    @XmlAttribute
	private String zcs;

    @XmlAttribute
	private float jzmj;

    @XmlAttribute
	private float zyjzmj;

    @XmlAttribute
	private float ftjzmj;

    @XmlAttribute
    @Nullable
	private String jgsj;

    @XmlAttribute
    @Nullable
	private String bdcqzh;

    @XmlAttribute
    @qxdm
	private String qxdm;

    @XmlAttribute
	private String djjg;

    @XmlAttribute
	private String dbr;

    @XmlAttribute
	private Date djsj;

    @XmlAttribute
    @Nullable
	private String fj;

    @XmlAttribute
	private String qszt;

    @Nullable
    private Date sjgxsj;

    @bwmc
    private String bwmc;

    public String getBwmc() {
        return bwmc;
    }

    public void setBwmc(String bwmc) {
        this.bwmc = bwmc;
    }

    public Date getSjgxsj() {
        return sjgxsj;
    }

    public void setSjgxsj(Date sjgxsj) {
        this.sjgxsj = sjgxsj;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getYsdm() {
        return ysdm;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public String getYwh() {
        return ywh;
    }

    public String getQllx() {
        return qllx;
    }

    public String getDjlx() {
        return djlx;
    }

    public String getDjyy() {
        return djyy;
    }

    public String getFdzl() {
        return fdzl;
    }

    public String getTdsyqr() {
        return tdsyqr;
    }

    public String getDytdmj() {
        return dytdmj;
    }

    public String getFttdmj() {
        return fttdmj;
    }

    public Date getTdsyqssj() {
        return tdsyqssj;
    }

    public Date getTdsyjssj() {
        return tdsyjssj;
    }

    public String getFdcjyjg() {
        return fdcjyjg;
    }

    public String getGhyt() {
        return ghyt;
    }

    public String getFwxz() {
        return fwxz;
    }

    public String getFwjg() {
        return fwjg;
    }

    public String getSzc() {
        return szc;
    }



    public float getJzmj() {
        return jzmj;
    }

    public float getZyjzmj() {
        return zyjzmj;
    }

    public float getFtjzmj() {
        return ftjzmj;
    }

    public String getJgsj() {
        return jgsj;
    }

    public String getBdcqzh() {
        return bdcqzh;
    }

    public String getQxdm() {
        return qxdm;
    }

    public String getDjjg() {
        return djjg;
    }

    public String getDbr() {
        return dbr;
    }

    public Date getDjsj() {
        return djsj;
    }

    public String getFj() {
        return fj;
    }

    public String getQszt() {
        return qszt;
    }


    public void setYsdm(String ysdm) {
        this.ysdm = ysdm;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public void setDjlx(String djlx) {
        this.djlx = djlx;
    }

    public void setDjyy(String djyy) {
        this.djyy = djyy;
    }

    public void setFdzl(String fdzl) {
        this.fdzl = fdzl;
    }

    public void setTdsyqr(String tdsyqr) {
        this.tdsyqr = tdsyqr;
    }

    public void setDytdmj(String dytdmj) {
        this.dytdmj = dytdmj;
    }

    public void setFttdmj(String fttdmj) {
        this.fttdmj = fttdmj;
    }

    public void setTdsyqssj(Date tdsyqssj) {
        this.tdsyqssj = tdsyqssj;
    }

    public void setTdsyjssj(Date tdsyjssj) {
        this.tdsyjssj = tdsyjssj;
    }

    public void setFdcjyjg(String fdcjyjg) {
        this.fdcjyjg = fdcjyjg;
    }

    public void setGhyt(String ghyt) {
        this.ghyt = ghyt;
    }

    public void setFwxz(String fwxz) {
        this.fwxz = fwxz;
    }

    public void setFwjg(String fwjg) {
        this.fwjg = fwjg;
    }

    public void setSzc(String szc) {
        this.szc = szc;
    }

    public String getZcs() {
        return zcs;
    }

    public void setZcs(String zcs) {
        this.zcs = zcs;
    }

    public void setJzmj(float jzmj) {
        this.jzmj = jzmj;
    }

    public void setZyjzmj(float zyjzmj) {
        this.zyjzmj = zyjzmj;
    }

    public void setFtjzmj(float ftjzmj) {
        this.ftjzmj = ftjzmj;
    }

    public void setJgsj(String jgsj) {
        this.jgsj = jgsj;
    }

    public void setBdcqzh(String bdcqzh) {
        this.bdcqzh = bdcqzh;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }

    public void setDjjg(String djjg) {
        this.djjg = djjg;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public void setQszt(String qszt) {
        this.qszt = qszt;
    }

}
